function [p, c, e] = fit(p, u, v, f, u0, v0, f0),

% FIT Fit a B-Spline to the data (u, v, f), with 1 optional 
% constraint (u0, v0, f0). 
% 
% FIT(p, u, v, f, ...).  Here p is the B-Spline, (u, v, f) is the data, 
% and 1 additional constraint is OK to pass through. 
%
% FIT(p, u, v, f, u0, v0, f0).  The additional constraint is given by 
% (u0, v0, f0).

if (nargin < 5),
    % unconstrained least squares
    D   = getM(p, u, v);   
    c   = D\f;
else 
    % constrained least squares
    D0          = getM(p, u0, v0);
    D           = getM(p, u, v);
    c           = c_lsq(D, f, D0, f0);
end

e           = D*c - f;
p.coeff     = reshape(c, size(p.coeff));  % added 29/10/06
return