function z = get(zk, x1, x2, varargin),

% GET From the Zernike polynomial object. 
% 
% GET(p, strf). Return field strf from the polynomial
%
% GET(p, x1, x2). Return the depth of Zernike polynomial
% at point (x1, x2) where the field 'coord' indicates whether 
% the requested point is { 'polar' (r, t) or 'cartesian' (x, y) }.
% 
% GET(p, x1, x2, strf).  Same as above with additional allowed fields 
% { 'dzdr', 'dzdt' } 
%


% added matrix return capability

if (nargin < 3),
   
    if (ischar(x1)),
        z = zk.(x1);
    else
        error('(GET) Unknown option');
    end
    return
end

if (strcmp(zk.coord,'cartesian')),
    [phi,r] = cart2pol(x1,x2);
    r       = r/zk.aperture;
else 
    r       = x1/zk.aperture;
    phi     = x2;
end


nr = size(r); r = r(:); phi = phi(:);


if (nargin == 3),
    M  = znkBasisOSAVec(zk.terms, r, phi);
    z  = M*zk.coeff; 
elseif (nargin == 4),
    switch(varargin{1}),
        case { 'z' },
            M  = znkBasisOSAVec(zk.terms, r, phi);
            z  = M*zk.coeff; 
        case { 'dzdr', 'rho' },
            M    = znkBasisOSADVec(zk.terms, r, phi, 'rho')*(1/zk.aperture);
        case { 'u','v','dzdx','dzdy' }
            dDdr    = znkBasisOSADVec(zk.terms, r, phi, 'rho')*(1/zk.aperture);
            dDdphi  = znkBasisOSADVec(zk.terms, r, phi, 'phi');
            n       = size(dDdr,2);
            phi     = phi(:,ones([ 1 n ] ));
            r       = r(:,ones([ 1 n ] ));
            M       = dpol2dcar(phi, r*zk.aperture, dDdphi, dDdr, varargin{1});
        otherwise,
            M    = znkBasisOSADVec(zk.terms, r, phi, varargin{1});
    end
    z  = M*zk.coeff; 
else
    error('(ZNK/GET) Unknown invocation');    
end

% assumes size(r) == size(phi)

if (nr(2) > 1),
    z  = reshape(z, nr);    
end
return