% DEMO1 Demonstrate how to use the Zernike representation.
%

disp('Demonstrate how to use the zernike representation.');

nOrder  = 10;       % order of polynomial
nApR    = 1;        % aperture radius 

% example zernike coeffs.
CV  = 1/7;   % radius of curvature 
CC  = 0;     % conic constant 
nC = znkConicCoeffs(CV, CC, nApR, nOrder); 

% construct and print the zernike object 
p = znk(nOrder);    % 10^th order Zernike 
p  = set(p, 'coeff', nC);                  
p  = set(p, 'aperture', nApR);             % aperture radius of unity 
p  = set(p, 'coord', 'cartesian');         % 'cartesian' input.
print(p);                                  % display. 


% make some test points 
r = rand([16 1]);
t = rand([16 1])*360;
t = t*pi/180;
[x, y] = pol2cart(t(:), r(:)); 

z   = get(p, x, y);         % depth or "sag." (i.e., an optical term).
z_0 = conic(x, y, CV, CC);
e   = abs(z - z_0);

fprintf('\n\n--------------------------------------------------------------------\n');
fprintf('(x,y)               / Zernike        /Actual          /Error\n');
fprintf('--------------------------------------------------------------------\n');
fprintf('(%4.2f, %4.2f)      %2.6f        %2.6f        %4.2e\n', [ x, y, z, z_0, e]');
fprintf('--------------------------------------------------------------------\n');






