function y = bhwRadialTermStr(n, m),

% BHWRADIALTERMSTR Bhatia-Wolf radial component of the term string 
% for polynomial-ordering number p
%
% BHWRADIALTERMSTR(n, m). Here (n, m) is the combination of 
% (radial order, azimuthal frequency). 
%
% see BHWTERM for details of the Bhatia-Wolf polynomials.
%
% implements Bhatia=Wolf polynomials as described in : 
%
% Modeling of Corneal Surfaces with Radial Polynomials. Iskander, DR;
% Morelande, MR; Collins MJ; Davis, B. IEEE Trams. Biomed. Eng. 49(4) April
% 2002. 


if ((n==0)&(m==0))
    y = '1';  % N_mn = 0
    return
end

if      (m < n),
        y0 = bhwRadialCoeff(n, m);
        if (n ~= 1) 
            y = sprintf('%.0f*r^%d',[y0(1) n]);
        else
            y = sprintf('%.0f*r',y0(1));
        end 
        
        % normal construction 
        for s = 1:(n-m)
            % next polynomial term
            if  (n-s == 0),
                % constant term    
                y = strcat(y, sprintf('%+.0f',y0(s+1)));
            elseif  (n-s == 1),
                % drop the power 
                y = strcat(y, sprintf('%+.0f*r',y0(s+1)));        
            else
                % non-constant term
                y1 = sprintf('%+.0f*r^%d',y0(s+1),n-s);
                y = strcat(y, y1);
            end
        end 
        
elseif  (m == n)
        % this is a stand-alone term
        if  (n > 1),
            y = sprintf('r^%d',n);            
        else
            y = 'r';
        end 
else
        error('m > n not allowed.');
end
return