function y = bhwTermStr(p),

% BHWTERMSTR Bhatia-Wolf term string for polynomial-ordering number p
%
% BHWTERMSTR(p). Where p is the polynomial-ordering number.
%
% see BHWTERM for details of the Bhatia-Wolf polynomials.
%
%
% implements Bhatia=Wolf polynomials as described in : 
%
% Modeling of Corneal Surfaces with Radial Polynomials. Iskander, DR;
% Morelande, MR; Collins MJ; Davis, B. IEEE Trams. Biomed. Eng. 49(4) April
% 2002. 

% single indexing to double 
n    = ceil(sqrt(p)) - 1;
m    = floor((p-((n-1)^2+2*(n-1)+1))/2);

if ((n==0)&(m==0))
    y = '1';  % N_mn = 0
    return
end

str = bhwRadialTermStr(n, m);

% azimuthal partbasisOSAstring
if (m ~= 0),    
    
    
        if (m == 1),

            if  (mod(p,2)),
                % odd
                y = strcat('(',str,')*sin(phi)');   
            else
                % even
                y = strcat('(',str,')*cos(phi)');   
            end
        else 
            % angular part 
            if  (mod(p,2)),
                % odd
                y = strcat('(',str,')*sin(', num2str(m) ,'*phi)');   
            else
                % even
                y = strcat('(',str,')*cos(', num2str(m) ,'*phi)');   
            end
        end
else
    y = str;
end

% normalization 
if  (m==0),
     N_mn = n+1;
else
     N_mn = 2*(n+1);
end

% normalize only if N_mn > 1
if  (N_mn > 1),
    y = strcat(sprintf('sqrt(%d)*',N_mn),[ '(' y ')' ]);    
end 

return