% testTerms 
%
% test that terms from the String function 
% are the same as the calculated terms 

p = 2;

r   = (0:0.1:1);
t   = degtorad(0:30:360);
[t,r] = meshgrid(t,r);
t = t(:); r = r(:);


disp('test : Matching bhwTerm with inline bhwTermString');

for p = 2:25,

    [n, m] = bhwSgl2Dbl(p);
    
    fprintf(1, 'p = %d, n = %d, m = %d ',[p n m]);
    
    y   = inline(bhwTermStr(p),'r','phi','m');
    y1   = y(r, t, m);
    y0  = bhwTerm(r, t, p);
    e   = abs(y1-y0);

    fprintf(1,'formula = %s ',char(y));
    fprintf(1,'Maxi. err.=%2.2f', max(e));
    
    if (max(e) < 1e-8),
        
        fprintf(1,'... passed.\n');
    else
        fprintf(1,'... failed.\n');
    end
end


disp('test : Matching bhwTermDv with numerical derivatives mkDerivFn');
for p = 2:25,

    [n, m] = bhwSgl2Dbl(p);
    
    fprintf(1, 'p = %d, n = %d, m = %d ',[p n m]);
    
    
    y_r         = bhwTermDv(r, t, p, 'rho');
    y_t         = bhwTermDv(r, t, p, 'phi');
    
    [n, m]       = bhwSgl2Dbl(p);    
    [dfdr, dfdt] = mkDerivFn(r,t,inline(bhwTermStr(p),'r','phi','m'),m);
      
    
    e1   = abs(y_r-dfdr);
    e2   = abs(y_t-dfdt);

    fprintf(1,'Maxi. err.=(%2.2f, %2.2f)', [ max(e1) max(e2) ]);
    
    if (max(e1) < 1e-4),
        fprintf(1,'... passed/');
    else
        fprintf(1,'... failed/');
    end
    
    if (max(e2) < 1e-4),
        fprintf(1,'passed\n');
    else
        fprintf(1,'failed(%e, %e)\n',[ y_t(p) dfdt(p) ]');
    end
    
end 


disp('test : Matching bhwTermDv with bhwTermStrDv');
for p = 2:25,

    [n, m] = bhwSgl2Dbl(p);
    
    fprintf(1, 'p = %d, n = %d, m = %d ',[p n m]);
    
    y_r0         = inline(bhwTermDvStr(p, 'rho'),'r','phi','m'); 
    y_t0         = inline(bhwTermDvStr(p, 'phi'),'r','phi','m'); 
    
    dfdr        = y_r0(r, t, m);
    dfdt        = y_t0(r, t, m);
    
    y_r         = bhwTermDv(r, t, p, 'rho');
    y_t         = bhwTermDv(r, t, p, 'phi');
        
    e1          = abs(y_r-dfdr);
    e2          = abs(y_t-dfdt);

    fprintf(1,'formula = (%s, ', char(y_r0));
    fprintf(1,'%s)\n', char(y_t0));
    fprintf(1,'Maxi. err.=(%2.2f, %2.2f)', [ max(e1) max(e2) ]);
    
    if (max(e1) < 1e-4),
        fprintf(1,'... passed/');
    else
        fprintf(1,'... failed/');
    end
    
    if (max(e2) < 1e-4),
        fprintf(1,'passed\n');
    else
        fprintf(1,'failed(%e, %e)\n',[ y_t(p) dfdt(p) ]');
    end
    
end 