function [f, varargout] = sphere(x, y, R, str),

% SPHERE Define a sphere along the z-axis with apex at the origin.  
% 
% SPHERE(x, y, R, str). The pair (x, y) is the position in the (x, y) plane, 
% R is the radius of curvature, and str is { 'z', 'dzdx', 'dzdy','normal' }.  If
% strf is omitted, the height ('z') will be returned. 
%
% [R, nArgList ] = SPHERE('default').  Returns information for the RAYTRACE 
% toolbox, namely a default spherical surface, along withe argument list.
%
% f = SPHERE('inline').  Returns an inline version of the depth function ('z')   .
%
% Examples,
%   
%   nArgs = sphere('default');
%   z = sphere(1, 1.5, nArgs{:})
%   z = sphere('inline'); z(1, 1.5, nArgs{:})


% NOTES :  
% 5/12/06 added +ve/-ve radius to R.

if  ((nargin == 1)&(ischar(x))),
    switch(x),
        case { 'default' }
             f = { 7 }; 
             varargout = { {'R'} };
        case { 'inline' },
            % bug 15/3/06 - added squares to the r's [DOES THAT AFFECT PAPER]
            % z   = inline('(CV*r^2)/(1 + sqrt(1 - (CV^2)*(CC+1)*r^2))','r','CV','CC');
            f  = 'R - sign(R).*sqrt(R^2 - x.^2 - y.^2)';
            f = inline(f, 'x', 'y', 'R');      
        otherwise,
            error('(SPHERE) Unknown invocation parameter.');
    end
    return
end


% sphere height 
f  = R - sign(R).*sqrt(R^2 - x.^2 - y.^2);
if (nargin == 3),
    return
end

switch(str)
 case 'z'
    return
 % added 'dzdr'
 case 'dzdr'
    r = sqrt(x.^2 + y.^2);
    f = r./(R-f);
    return
 case 'd2zdr2'
    r  = sqrt(x.^2 + y.^2);
    f  = (1./(R-f)) + ((r.^2)./(R-f).^3);     
    return
 case 'dzdx'
    f = x./(R-f);
    return
 case 'dzdy'
    f = y./(R-f);
    return
 case 'normal'
    f0     = f; % bug detected   
    f(:,1) = x./(R-f0);
    f(:,2) = y./(R-f0);
    f(:,3) = -1;
    return;
 otherwise
     error('SPHERE unknown aspect requested.');
end
return
