% TEST_BHW consistency check on BHW methods. 
%
%
% perform some tests on the Bhatia-Wolf object
%
%   - 
%   - get
%   - getMdv
%
%
%

fprintf('creating BHW object\n');
nOrder = 10; nAp = 4.1;
z = bhw(nOrder);
z = set(z, 'aperture', nAp);
z = set(z, 'coord', 'cartesian');

t0 = linspace(0, 2*pi, 40); t0 = t0(2:end);
r0 = linspace(0, 4, 40);   r0 = r0(2:end);
[ t0, r0 ] = meshgrid(t0, r0);
[ x0, y0 ] = pol2cart(t0, r0);
x0 = x0(:); y0 = y0(:);
t0 = t0(:); r0 = r0(:);

z0  = ellipsoid(x0, y0, 8, 9, 10);
z   = fit(z, x0, y0, z0);
z1  = get(z, x0, y0);

e   = abs(z1- z0);
e   = e(:);

fprintf('FITTING TO SURFACE\n');
fprintf('  MAX. ERROR = %6.4e\n', max(e));
fprintf('  RMS. ERROR = %6.4e\n', std(e));


fprintf('CHECKING HEIGHT MATRIX\n');
M = getM(z, x0, y0);
nTerm = bhwOrder2Terms(nOrder);
for p = 1:nTerm,
    fn = vectorize(inline(bhwTermStr(p),'r','phi'));
    if (p > 1),
        Mchk = fn(r0/nAp, t0);
    else
        Mchk = r0*0 + 1;
    end 
    
    e = abs(Mchk - M(:, p));
    fprintf('%d. CHECKED ... ERR = %6.4e\n', p, max(e));
end


fprintf('CHECKING X-DERIV MATRIX\n');
Mx = getMdv(z, x0, y0, 'dzdx');
My = getMdv(z, x0, y0, 'dzdy');
nTerm = bhwOrder2Terms(nOrder);
for p = 1:nTerm,
        
    fdzdr = inline(bhwTermDvStr(p,'rho'),'r','phi');
    fdzdt = inline(bhwTermDvStr(p,'phi'),'r','phi');
    
    fdzdr = vectorize(fdzdr);
    fdzdt = vectorize(fdzdt);
    
     % ... 
     dMzdr = fdzdr(r0/nAp,t0)*1/nAp;
     dMzdt = fdzdt(r0/nAp,t0);
    
     if (length(dMzdr) == 1),
         dMzdr = dMzdr + 0*t0;
     end
        
     if (length(dMzdt) == 1),
         dMzdt = dMzdt + 0*t0;
     end
        
     dMx   = dpol2dcar(t0, r0, dMzdt, dMzdr, 'dzdx');
     dMy   = dpol2dcar(t0, r0, dMzdt, dMzdr, 'dzdy');
        
     e = abs(dMx - Mx(:, p));
     fprintf('%d. CHECKED X ... ERR = %6.4e\n', p, max(e));
     e = abs(dMy - My(:, p));
     fprintf('%d. CHECKED Y ... ERR = %6.4e\n', p, max(e));
             
    end
end